@@ -1534,11 +1534,12 @@ void KDirListerTest::testMimeFilter_data()
     QTest::addColumn<QStringList>("mimeTypes");
     QTest::addColumn<QStringList>("filteredFiles");
 
-    const QStringList files = {"bla.txt", "main.cpp", "main.c", "image.jpeg"};
+    const QStringList files = {"bla.txt", "main.cpp", "main.c", "image.jpeg", "picture.png"};
 
     QTest::newRow("single_file_exact_mimetype") << files << QStringList{"text/x-c++src"} << QStringList{"main.cpp"};
     QTest::newRow("inherited_mimetype") << files << QStringList{"text/plain"} << QStringList{"bla.txt", "main.cpp", "main.c"};
     QTest::newRow("no_match") << files << QStringList{"audio/flac"} << QStringList{};
+    QTest::newRow("glob") << files << QStringList{"image/*"} << QStringList{"image.jpeg", "picture.png"};
 }
 
 void KDirListerTest::testMimeFilter()
@@ -1687,7 +1688,7 @@ void KDirListerTest::testBug386763()
 
     // Create a file in 'newsubdir' while still opened in dirLister2
     // bug was that the watch on ’newsubdir’ when dirLister left this dir
-    // eventhough dirLister2 is still listing it
+    // even though dirLister2 is still listing it
     QCOMPARE(dirLister2.spyCompleted.count(), 1);
     createTestFile(path + "newFile-1");
 
@@ -1874,14 +1875,14 @@ void KDirListerTest::testSFTPRedirect()
     dirLister.openUrl(testUrl);
     QVERIFY(dirLister.spyCompleted.wait(500));
     // Make sure we have the items listed properly on the first time.
-    QVERIFY(dirLister.items().count() == 2);
+    QCOMPARE(dirLister.items().count(), 2);
 
     // This should not crash!
     dirLister.openUrl(testUrl);
     QVERIFY(dirLister.spyCompleted.wait(500));
     // This should not list any items: We have already done it in the previous iteration.
     // If this lists items, the view (for example in Dolphin) will have the items duplicated.
-    QVERIFY(dirLister.items().count() == 0);
+    QCOMPARE(dirLister.items().count(), 0);
 }
 
 #include "moc_kdirlistertest.cpp"
