@@ -42,7 +42,7 @@ struct UDSTestField {
     long long m_long;
 };
 
-/**
+/*!
  * Test that storing UDSEntries to a stream and then re-loading them works.
  */
 void UDSEntryTest::testSaveLoad()
@@ -192,7 +192,7 @@ void UDSEntryTest::testSaveLoad()
     }
 }
 
-/**
+/*!
  * Test to verify that move semantics work. This is only useful when ran through callgrind.
  */
 void UDSEntryTest::testMove()
@@ -239,7 +239,7 @@ void UDSEntryTest::testMove()
     }
 }
 
-/**
+/*!
  * Test to verify that equal semantics work.
  */
 void UDSEntryTest::testEquality()
@@ -307,6 +307,13 @@ void UDSEntryTest::testEquality()
     QVERIFY(entry2 == entry3);
     QVERIFY(!(entry != entry3));
     QVERIFY(!(entry2 != entry3));
+
+    // we're just checking that this compiles
+    KIO::UDSEntryList list1;
+    KIO::UDSEntryList list2;
+    QVERIFY(list1 == list2);
+    list2 << entry;
+    QVERIFY(list1 != list2);
 }
 
 QTEST_MAIN(UDSEntryTest)
