@@ -88,10 +88,6 @@ public:
         if (!(flags & HideProgressInfo)) {
             KIO::getJobTracker()->registerJob(job);
         }
-        if (!(flags & NoPrivilegeExecution)) {
-            job->d_func()->m_privilegeExecutionEnabled = true;
-            job->d_func()->m_operationType = MkDir;
-        }
         return job;
     }
 };
