@@ -26,7 +26,6 @@
 #include <QFile>
 #include <QList>
 #include <QMap>
-#include <QSsl>
 #include <QtGlobal>
 
 #include <KAboutData>
@@ -51,10 +50,6 @@
 #include "kpasswdserverclient.h"
 #include "workerinterface_p.h"
 
-#if defined(Q_OS_UNIX) && !defined(Q_OS_ANDROID)
-#include <KAuth/Action>
-#endif
-
 // TODO: Enable once file KIO worker is ported away and add endif, similar in the header file
 // #if KIOCORE_BUILD_DEPRECATED_SINCE(version where file:/ KIO worker was ported)
 
@@ -99,8 +94,6 @@ public:
     explicit SlaveBasePrivate(SlaveBase *owner)
         : q(owner)
         , nextTimeoutMsecs(0)
-        , m_confirmationAsked(false)
-        , m_privilegeOperationStatus(OperationNotAllowed)
     {
         if (!qEnvironmentVariableIsEmpty("KIOWORKER_ENABLE_TESTMODE")) {
             QStandardPaths::setTestModeEnabled(true);
@@ -139,7 +132,13 @@ public:
     qint64 nextTimeoutMsecs;
     KIO::filesize_t totalSize;
     KRemoteEncoding *remotefile = nullptr;
-    enum { Idle, InsideMethod, InsideTimeoutSpecial, FinishedCalled, ErrorCalled } m_state;
+    enum {
+        Idle,
+        InsideMethod,
+        InsideTimeoutSpecial,
+        FinishedCalled,
+        ErrorCalled
+    } m_state;
     bool m_finalityCommand = true; // whether finished() or error() may/must be called
     QByteArray timeoutData;
 
@@ -148,32 +147,6 @@ public:
 #endif
     bool m_rootEntryListed = false;
 
-    bool m_confirmationAsked;
-    QSet<QString> m_tempAuths;
-    QString m_warningTitle;
-    QString m_warningMessage;
-    int m_privilegeOperationStatus;
-
-    void updateTempAuthStatus()
-    {
-#if defined(Q_OS_UNIX) && !defined(Q_OS_ANDROID)
-        QSet<QString>::iterator it = m_tempAuths.begin();
-        while (it != m_tempAuths.end()) {
-            KAuth::Action action(*it);
-            if (action.status() != KAuth::Action::AuthorizedStatus) {
-                it = m_tempAuths.erase(it);
-            } else {
-                ++it;
-            }
-        }
-#endif
-    }
-
-    bool hasTempAuth() const
-    {
-        return !m_tempAuths.isEmpty();
-    }
-
     // Reconstructs configGroup from configData and mIncomingMetaData
     void rebuildConfig()
     {
@@ -367,7 +340,6 @@ void SlaveBase::dispatchLoop()
                 disconnectSlave();
                 d->isConnectedToApp = false;
                 closeConnection();
-                d->updateTempAuthStatus();
                 connectSlave(d->poolSocket);
             } else {
                 break;
@@ -554,8 +526,6 @@ void SlaveBase::error(int _errid, const QString &_text)
     // reset
     d->totalSize = 0;
     d->inOpenLoop = false;
-    d->m_confirmationAsked = false;
-    d->m_privilegeOperationStatus = OperationNotAllowed;
 }
 
 void SlaveBase::connected()
@@ -614,16 +584,6 @@ void SlaveBase::finished()
     d->totalSize = 0;
     d->inOpenLoop = false;
     d->m_rootEntryListed = false;
-    d->m_confirmationAsked = false;
-    d->m_privilegeOperationStatus = OperationNotAllowed;
-}
-
-void SlaveBase::slaveStatus(const QString &host, bool connected)
-{
-    qint64 pid = getpid();
-    qint8 b = connected ? 1 : 0;
-    KIO_DATA << pid << mProtocol << host << b << d->onHold << d->onHoldUrl << d->hasTempAuth();
-    send(MSG_WORKER_STATUS, data);
 }
 
 void SlaveBase::canResume()
@@ -703,8 +663,7 @@ static bool isSubCommand(int cmd)
     /* clang-format off */
     return cmd == CMD_REPARSECONFIGURATION
         || cmd == CMD_META_DATA
-        || cmd == CMD_CONFIG
-        || cmd == CMD_WORKER_STATUS;
+        || cmd == CMD_CONFIG;
     /* clang-format on */
 }
 
@@ -969,11 +928,6 @@ void SlaveBase::chown(QUrl const &, const QString &, const QString &)
     error(ERR_UNSUPPORTED_ACTION, unsupportedActionErrorString(protocolName(), CMD_CHOWN));
 }
 
-void SlaveBase::slave_status()
-{
-    slaveStatus(QString(), false);
-}
-
 void SlaveBase::reparseConfiguration()
 {
     delete d->remotefile;
@@ -1147,14 +1101,6 @@ void SlaveBase::dispatch(int command, const QByteArray &data)
         closeConnection();
         break;
     }
-    case CMD_WORKER_STATUS: {
-        d->m_state = d->InsideMethod;
-        d->m_finalityCommand = false;
-        slave_status();
-        // TODO verify that the slave has called slaveStatus()?
-        d->m_state = d->Idle;
-        break;
-    }
     case CMD_REPARSECONFIGURATION: {
         d->m_state = d->InsideMethod;
         d->m_finalityCommand = false;
@@ -1415,6 +1361,7 @@ bool SlaveBase::cacheAuthentication(const AuthInfo &info)
     return true;
 }
 
+#if KIOCORE_BUILD_DEPRECATED_SINCE(6, 11)
 int SlaveBase::connectTimeout()
 {
     bool ok;
@@ -1425,7 +1372,9 @@ int SlaveBase::connectTimeout()
     }
     return DEFAULT_CONNECT_TIMEOUT;
 }
+#endif
 
+#if KIOCORE_BUILD_DEPRECATED_SINCE(6, 11)
 int SlaveBase::proxyConnectTimeout()
 {
     bool ok;
@@ -1436,7 +1385,9 @@ int SlaveBase::proxyConnectTimeout()
     }
     return DEFAULT_PROXY_CONNECT_TIMEOUT;
 }
+#endif
 
+#if KIOCORE_BUILD_DEPRECATED_SINCE(6, 11)
 int SlaveBase::responseTimeout()
 {
     bool ok;
@@ -1447,7 +1398,9 @@ int SlaveBase::responseTimeout()
     }
     return DEFAULT_RESPONSE_TIMEOUT;
 }
+#endif
 
+#if KIOCORE_BUILD_DEPRECATED_SINCE(6, 11)
 int SlaveBase::readTimeout()
 {
     bool ok;
@@ -1458,6 +1411,7 @@ int SlaveBase::readTimeout()
     }
     return DEFAULT_READ_TIMEOUT;
 }
+#endif
 
 bool SlaveBase::wasKilled() const
 {
@@ -1509,69 +1463,3 @@ void SlaveBase::setRunInThread(bool b)
 {
     d->runInThread = b;
 }
-
-void SlaveBase::lookupHost(const QString &host)
-{
-    KIO_DATA << host;
-    send(MSG_HOST_INFO_REQ, data);
-}
-
-int SlaveBase::waitForHostInfo(QHostInfo &info)
-{
-    QByteArray data;
-    int result = waitForAnswer(CMD_HOST_INFO, 0, data);
-
-    if (result == -1) {
-        info.setError(QHostInfo::UnknownError);
-        info.setErrorString(i18n("Unknown Error"));
-        return result;
-    }
-
-    QDataStream stream(data);
-    QString hostName;
-    QList<QHostAddress> addresses;
-    int error;
-    QString errorString;
-
-    stream >> hostName >> addresses >> error >> errorString;
-
-    info.setHostName(hostName);
-    info.setAddresses(addresses);
-    info.setError(QHostInfo::HostInfoError(error));
-    info.setErrorString(errorString);
-
-    return result;
-}
-
-PrivilegeOperationStatus SlaveBase::requestPrivilegeOperation(const QString &operationDetails)
-{
-    if (d->m_privilegeOperationStatus == OperationNotAllowed) {
-        QByteArray buffer;
-        send(MSG_PRIVILEGE_EXEC);
-        waitForAnswer(MSG_PRIVILEGE_EXEC, 0, buffer);
-        QDataStream ds(buffer);
-        ds >> d->m_privilegeOperationStatus >> d->m_warningTitle >> d->m_warningMessage;
-    }
-
-    if (metaData(QStringLiteral("UnitTesting")) != QLatin1String("true") && d->m_privilegeOperationStatus == OperationAllowed && !d->m_confirmationAsked) {
-        // WORKER_MESSAGEBOX_DETAILS_HACK
-        // SlaveBase::messageBox() overloads miss a parameter to pass an details argument.
-        // As workaround details are passed instead via metadata before and then cached by the WorkerInterface,
-        // to be used in the upcoming messageBox call (needs WarningContinueCancelDetailed type)
-        // TODO: add a messageBox() overload taking details and use here,
-        // then remove or adapt all code marked with WORKER_MESSAGEBOX_DETAILS
-        setMetaData(QStringLiteral("privilege_conf_details"), operationDetails);
-        sendMetaData();
-
-        int result = messageBox(d->m_warningMessage, WarningContinueCancelDetailed, d->m_warningTitle, QString(), QString(), QString());
-        d->m_privilegeOperationStatus = result == Continue ? OperationAllowed : OperationCanceled;
-        d->m_confirmationAsked = true;
-    }
-
-    return KIO::PrivilegeOperationStatus(d->m_privilegeOperationStatus);
-}
-
-void SlaveBase::addTemporaryAuthorization(const QString &action)
-{
-    d->m_tempAuths.insert(action);
-}
